/**
 * @file
 * Attaches administration-specific behavior for the Filter module.
 */

(function ($, Drupal) {
  /**
   * Displays and updates the status of filters on the admin page.
   *
   * @type {Drupal~behavior}
   *
   * @prop {Drupal~behaviorAttach} attach
   *   Attaches behaviors to the filter admin view.
   */
  Drupal.behaviors.PageLinks = {
    attach(context, settings) {

      let editor = null;

      function getCkeditor() {
        if (!editor && $('.ck-content').length) {
          editor = Drupal.CKEditor5Instances.get(
            Drupal.CKEditor5Instances.keys().next().value,
          );
        }
      }

      setTimeout(function () {
        getCkeditor();
      }, 500);

      // Generate ftp dsn string by link click.
      $(once('deleteLink', '.delete-link')).on(
        'click',
        (event) => {
          event.preventDefault();

          let t = $(event.target);
          const Links = settings['PageLinks'] || [];

          if (editor && $('.ck-content').length) {
              curValue = editor.getData();

              let link_id = t.attr('data-link-id');
              let link_full = Links[link_id][0];
              let link_text = Links[link_id][2];
              // Remove link by inner text.
              curValue = curValue.replace(link_full, link_text);
              getCkeditor();
              // Delele link from editor.
              editor.setData(curValue);

              // Finally hide delete link.
              t.hide();
              // Mark roe as delted.
              t.parents('tr').addClass('deleted');
              // Display Apply button
             $('#edit-page-links-save').show();
          }

        return false;
        });

      // Generate ftp dsn string by link click.
      $(once('gotoLink', '.goto-link')).on(
        'click',
        (event) => {
          event.preventDefault();

          let t = $(event.target);
          const Links = settings['PageLinks'] || [];

          if (editor && $('.ck-content').length) {
            let link_id = t.attr('data-link-id');
            let link_full = Links[link_id][0];
            getCkeditor();
            // Scroll editor area to clicked link.
            scrollToLink(editor, link_full);
          }

          return false;
        });

      function scrollToLink(editor, link) {
            const editorContent = $(editor.editing.view.domConverter.viewToDom(editor.editing.view.document.getRoot(), document));
            const textNode = editorContent.find('a').filter(
            function (i, el) {
              // Compare full <a> tag html code like: <a href="/test">text</a>
              return el.outerHTML == link;
            }).get(0);

            if (textNode) {
              $(textNode).get(0).scrollIntoView({ behavior: 'smooth', block: 'center' });
              // HighLight link.
              highLightLink(textNode);
            }
      }

      /**
       * Highlight the scrolled link.
       */
      function highLightLink(link){
        $(link).css('background-color', 'yellow');
        setTimeout(() => { $(link).removeAttr('style'); }, 2000);
      }

    },
  };
})(jQuery, Drupal);
