<?php

namespace Drupal\page_links;

use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\Core\Render\Markup;
use Drupal\Core\Link;

/**
 * @todo Add class description.
 */
class PageLinkService {

  use StringTranslationTrait;

  const LINKS_PATTERN = '/<a href=["\']([^"\']+)["\'].*?>(.+?)<\/a>/i';

  public function themeLinksTable($links) {
    $header = ['Del', $this->t('Type'), $this->t('Link URL')];
    $rows = [];
    foreach ($links as $link_data) {
      $rows[] = [
        'data' => [
          [
            'data' => $this->prepareLink($link_data, 'delete'),
            'class' => 'del',
          ],
          ['data' => $this->getLinkType($link_data[1]), 'class' => 'type'],
          ['data' => $this->prepareLink($link_data)],
        ],
        'class' => 'row-link-' . $this->getLinkType($link_data[1]),
      ];
    }

    $build = [
      '#type' => 'table',
      '#header' => $header,
      '#rows' => $rows,
      '#attributes' => ['class' => ['page-links-table']],
    ];

    return $build;
  }

  /**
   * Return link type local (L) or remote (R).
   *
   * @param string $url
   *
   *
   * @return string
   */
  private function getLinkType($url) {
    $info = parse_url($url);
    return empty($info['scheme']) ? 'L' : 'R';
  }

  /**
   * Grab links array from html text.
   *
   * @param $text
   *
   * @return array|void
   */
  public function getLinks($text = '') {
    if (!$text) {
      return;
    }

    $pattern = self::LINKS_PATTERN;
    // Array to hold the matches
    $matches = [];
    // Execute the regex
    if (!preg_match_all($pattern, $text, $matches)) {
      return;
    }
    // Check and print the matches
    $rows = [];
    foreach ($matches[1] as $key => $link) {
      $link_id = md5($matches[0][$key]);
      $rows[$link_id] = [
        $matches[0][$key],
        $matches[1][$key],
        $matches[2][$key],
      ];
    }
    return $rows;
  }

  /**
   *  Get link by type.
   *
   * @param $link
   * @param $type
   *
   * @return \Drupal\Component\Render\MarkupInterface|string
   */
  public function prepareLink($link, $type = '') {
    $link_text = htmlentities($link[2]);
    $link_url = htmlentities($link[1]);
    $link_id = md5($link[0]);

    if ($type == 'delete') {
      $result = '<a href="#" title="' . $this->t('Delete link') . '" data-link-id="' . $link_id . '" class="delete-link action-link--danger">[x]</a>';
    }
    else {
      $result = '<a href="#" class="link goto-link" title="' . $link_text . '" data-link-id="' . $link_id . '" >' . $link_url . '</a>';
    }

    return Markup::create($result);
  }

}
